@@ -388,6 +388,10 @@ class AzureContainerInstancesOperator(BaseOperator):
                     self.log.info("Container exited with detail_status %s", detail_status)
                     return exit_code
 
+                if state == "Unhealthy":
+                    self.log.error("Azure provision unhealthy")
+                    return 1
+
                 if state == "Failed":
                     self.log.error("Azure provision failure")
                     return 1
@@ -402,8 +406,7 @@ class AzureContainerInstancesOperator(BaseOperator):
                         "(make sure that the name is unique)."
                     )
                     return 1
-                else:
-                    self.log.exception("Exception while getting container groups")
+                self.log.exception("Exception while getting container groups")
             except Exception:
                 self.log.exception("Exception while getting container groups")
 
